@@ -58,8 +58,6 @@ const wchar_t kDefaultKeyboardLayout[] = L"00000411";
 const char kCompanyNameInEnglish[] = "Google";
 const char kEventPathPrefix[] = "Global\\GoogleJapaneseInput.event.";
 const char kMutexPathPrefix[] = "Global\\GoogleJapaneseInput.mutex.";
-const char kMozcServerName[] = "GoogleIMEJaConverter.exe";
-const char kOldIMEFile[] = "GoogleIMEJa.ime";
 const char kIMEFile[] = "GIMEJa.ime";
 const char kMozcBroker32[] = "GoogleIMEJaBroker32.exe";
 const char kMozcBroker64[] = "GoogleIMEJaBroker64.exe";
@@ -73,6 +71,8 @@ const wchar_t kCandidateWindowClassName[]
     = L"GoogleJapaneseInputCandidateWindow";
 const wchar_t kCompositionWindowClassName[]
     = L"GoogleJapaneseInputCompositionWindow";
+const wchar_t kInfolistWindowClassName[]
+    = L"GoogleJapaneseInpuInfolistWindow";
 // This UIWnd class name should be used by and only by the actual IMM32
 // version.  Make sure that |kIMEUIWndClassName| is different from
 // |kDummyIMEUIWndClassName| so that the dummy IME and the actual IME can
@@ -92,9 +92,7 @@ const wchar_t kElevatedProcessDisabledKey[]
 const char kCompanyNameInEnglish[] = "Mozc Project";
 const char kEventPathPrefix[] = "Global\\Mozc.event.";
 const char kMutexPathPrefix[] = "Global\\Mozc.mutex.";
-const char kMozcServerName[] = "mozc_server.exe";
-const char kOldIMEFile[] = "";
-const char kIMEFile[] = "mozc.ime";
+const char kIMEFile[] = "mozc_ja.ime";
 const char kMozcBroker32[] = "mozc_broker32.exe";
 const char kMozcBroker64[] = "mozc_broker64.exe";
 const char kMozcTool[] = "mozc_tool.exe";
@@ -107,7 +105,10 @@ const wchar_t kCandidateWindowClassName[]
     = L"MozcCandidateWindow";
 const wchar_t kCompositionWindowClassName[]
     = L"MozcCompositionWindow";
+const wchar_t kInfolistWindowClassName[]
+    = L"MozcInfolistWindow";
 const wchar_t kIMEUIWndClassName[] = L"MozcUIWindow";
+const char kIPCPrefix[] = "\\\\.\\pipe\\mozc.";
 const wchar_t kCandidateUIDescription[] = L"MozcCandidateUI";
 const wchar_t kConfigurationDisplayname[]
     = L"Mozc Configuration";
@@ -116,14 +117,12 @@ const wchar_t kElevatedProcessDisabledKey[]
     = L"Software\\Policies\\Mozc Project\\Mozc\\Preferences";
 #endif  // GOOGLE_JAPANESE_INPUT_BUILD
 #elif defined(OS_MACOSX)
-const char kMozcServerName[] = kProductPrefix "Converter.app";
 #ifdef GOOGLE_JAPANESE_INPUT_BUILD
 const char kEventPathPrefix[] = "GoogleJapaneseInput.event.";
 #else
 const char kEventPathPrefix[] = "Mozc.event.";
 #endif  // GOOGLE_JAPANESE_INPUT_BUILD
 #else  // OS_LINUX
-const char kMozcServerName[] = "mozc_server";
 const char kEventPathPrefix[] = "mozc.event.";
 const char kMozcTool[] = "mozc_tool";
 #endif
