@@ -32,8 +32,8 @@
 
 #ifdef OS_WINDOWS
 #include "base/const.h"
+#include "base/win_sandbox.h"
 #include "base/win_util.h"
-#include "third_party/mozc/sandbox/acl.h"
 #include <aclapi.h>
 #include <windows.h>
 #endif
@@ -52,6 +52,17 @@ const wchar_t kElevatedProcessDisabledName[]
 = L"elevated_process_disabled";
 
 #ifdef OS_WINDOWS
+// Returns true if both array have the same content.
+template <typename T, size_t ArraySize>
+bool AreEqualArray(const T (&lhs)[ArraySize], const T (&rhs)[ArraySize]) {
+  for (size_t i = 0; i < ArraySize; ++i) {
+    if (lhs[i] != rhs[i]) {
+      return false;
+    }
+  }
+  return true;
+}
+
 // returns true if the token was created by Secondary Logon
 // (typically via RunAs command) or UAC (w/ alternative credential provided)
 //  or if failed to determine.
@@ -81,8 +92,11 @@ bool IsDifferentUser(const HANDLE hToken) {
   // Sacrifice the last character. That is practically ok for our purpose.
   src.SourceName[TOKEN_SOURCE_LENGTH - 1] = '\0';
 
-  return (!::lstrcmpiA("seclogo", src.SourceName) ||
-          !::lstrcmpiA("CredPro", src.SourceName));
+  const char kSeclogo[] = "seclogo";
+  const char kCredPro[] = "CredPro";
+
+  return (AreEqualArray(kSeclogo, src.SourceName) ||
+          AreEqualArray(kCredPro, src.SourceName));
 }
 
 // Returns true if UAC gave the high integrity level to the token
@@ -168,7 +182,7 @@ RunLevel::RunLevelType RunLevel::GetRunLevel(RunLevel::RequestType type) {
   // Get thread token (if any)
   HANDLE hThreadToken = NULL;
   if (!::OpenThreadToken(::GetCurrentThread(),
-                        TOKEN_QUERY, TRUE, &hThreadToken) &&
+                         TOKEN_QUERY, TRUE, &hThreadToken) &&
       ERROR_NO_TOKEN != ::GetLastError()) {
     return RunLevel::DENY;
   }
@@ -190,9 +204,9 @@ RunLevel::RunLevelType RunLevel::GetRunLevel(RunLevel::RequestType type) {
   // Check whether the server/renderer is running inside sandbox.
   if (type == SERVER || type == RENDERER) {
     // Restricted token must be created by sandbox.
-    // Renderer is launched with NON_ADMIN, so it doesn't have
-    // restricted token.
-    if (type != RENDERER && !::IsTokenRestricted(process_token.get())) {
+    // Server is launched with NON_ADMIN so that it can use SSL access.
+    // This is why it doesn't have restricted token. b/5502343
+    if (type != SERVER && !::IsTokenRestricted(process_token.get())) {
       return RunLevel::DENY;
     }
 
@@ -230,11 +244,9 @@ RunLevel::RunLevelType RunLevel::GetRunLevel(RunLevel::RequestType type) {
         // In such a case, Mozc wouldn't work because Administrators identity
         // is removed by sandboxing so we should recover the permission here.
         // See http://b/2317718 for details.
-        sandbox::AddKnownSidToKernelObject(dir_handle.get(),
-                                           reinterpret_cast<SID *>(
-                                               ptoken_user->User.Sid),
-                                           SUB_CONTAINERS_AND_OBJECTS_INHERIT,
-                                           GENERIC_ALL);
+        WinSandbox::AddKnownSidToKernelObject(
+            dir_handle.get(), static_cast<SID *>(ptoken_user->User.Sid),
+            SUB_CONTAINERS_AND_OBJECTS_INHERIT, GENERIC_ALL);
       }
     }
 
