@@ -39,6 +39,9 @@
 #include "base/base.h"
 #include "transliteration/transliteration.h"
 #include "composer/composition_interface.h"
+#include "session/commands.pb.h"
+// for FRIEND_TEST()
+#include "testing/base/public/gunit_prod.h"
 
 namespace mozc {
 namespace commands {
@@ -52,6 +55,11 @@ class Table;
 
 class Composer {
  public:
+  // Pseudo commands in composer.
+  enum InternalCommand {
+    REWIND,
+  };
+
   Composer();
   virtual ~Composer();
 
@@ -59,7 +67,7 @@ class Composer {
   void Reset();
 
   // Reset input mode.  When the current input mode is
-  // HalfAlphanumeric by pressing capital alphabet, this function
+  // HalfAlphanumeric by pressing shifted alphabet, this function
   // revert the input mode from HalfAlphanumeric to the previous input
   // mode.
   void ResetInputMode();
@@ -79,6 +87,8 @@ class Composer {
 
   void SetInputMode(transliteration::TransliterationType mode);
   void SetTemporaryInputMode(transliteration::TransliterationType mode);
+  void SetInputFieldType(commands::SessionCommand::InputFieldType type);
+  commands::SessionCommand::InputFieldType GetInputFieldType() const;
 
   // Update the input mode considering the input modes of the
   // surrounding characters.
@@ -87,6 +97,7 @@ class Composer {
   void UpdateInputMode();
 
   transliteration::TransliterationType GetInputMode() const;
+  transliteration::TransliterationType GetComebackInputMode() const;
   void ToggleInputMode();
 
   transliteration::TransliterationType GetOutputMode() const;
@@ -112,7 +123,11 @@ class Composer {
   size_t GetCursor() const;
   void EditErase();
 
+  // Deletes a character at specified position.
   void DeleteAt(size_t pos);
+  // Delete multiple characters beginning at specified position.
+  void DeleteRange(size_t pos, size_t length);
+
   void InsertCharacter(const string &input);
   void InsertCharacterPreedit(const string &input);
   void InsertCharacterKeyAndPreedit(const string &key, const string &preedit);
@@ -121,6 +136,7 @@ class Composer {
                                       const string &key,
                                       const string &preedit);
   bool InsertCharacterKeyEvent(const commands::KeyEvent &key);
+  void InsertCommandCharacter(const InternalCommand internal_command);
   void Delete();
   void Backspace();
 
@@ -129,6 +145,7 @@ class Composer {
   void MoveCursorRight();
   void MoveCursorToBeginning();
   void MoveCursorToEnd();
+  void MoveCursorTo(uint32 new_position);
 
   // Generate transliterations.
   void GetTransliterations(transliteration::Transliterations *t13ns) const;
@@ -146,8 +163,6 @@ class Composer {
 
   // Check if the preedit is can be modified.
   bool EnableInsert() const;
-  void set_max_length(size_t length);
-  size_t max_length() const;
 
   // Automatically switch the composition mode according to the current
   // status and user's settings.
@@ -162,6 +177,10 @@ class Composer {
   // Return true if the composition is adviced to be committed immediately.
   bool ShouldCommit() const;
 
+  // Returns true if characters at the head of the preedit should be committed
+  // immediately.
+  bool ShouldCommitHead(size_t *length_to_commit) const;
+
   // Transform characters for preferred number format.  If any
   // characters are transformed true is returned.
   // For example, if the query is "ー１、０００。５", it should be
@@ -173,7 +192,33 @@ class Composer {
   // new chunk if the character has NewChunk attribute.
   void SetNewInput();
 
+  // These methods cannot copy composition_ correctly.
+  // TODO(hsumita): Do deep copy composition_ and add CopyFrom() method.
+  void CopyFromForSubmission(const Composer &src);
+  void CopyFromForConversion(const Composer &src);
+
+  bool is_new_input() const;
+  size_t shifted_sequence_count() const;
+  const string &source_text() const;
+  string *mutable_source_text();
+  void set_source_text(const string &source_text);
+  size_t max_length() const;
+  void set_max_length(size_t length);
+
  private:
+  FRIEND_TEST(ComposerTest, ApplyTemporaryInputMode);
+
+  // Copy composer except for composition_.
+  // Arguments are Source composer and query string for composition.
+  void CopyFromInternal(const Composer &src, const string &query);
+
+  // Change input mode temporarily accoding to the current context and
+  // the given input character.
+  // This function have a bug when key has characters input with Preedit.
+  // Expected behavior: InsertPreedit("A") + InsertKey("a") -> "Aあ"
+  // Actual behavior:   InsertPreedit("A") + InsertKey("a") -> "Aa"
+  void ApplyTemporaryInputMode(const string &key, bool caps_locked);
+
   size_t position_;
   // Whether the next insertion is the beginning of typing after an
   // editing command like SetInputMode or not.  Some conversion rules
@@ -185,9 +230,16 @@ class Composer {
   transliteration::TransliterationType output_mode_;
   // On reset, comeback_input_mode_ is used as the input mode.
   transliteration::TransliterationType comeback_input_mode_;
-  size_t capital_sequence_count_;
+  // Type of the input field to input texts.
+  commands::SessionCommand::InputFieldType input_field_type_;
+
+  size_t shifted_sequence_count_;
   scoped_ptr<CompositionInterface> composition_;
 
+  // The original text for the composition.  The value is usually
+  // empty, and used for reverse conversion.
+  string source_text_;
+
   size_t max_length_;
 
   DISALLOW_COPY_AND_ASSIGN(Composer);
