@@ -35,6 +35,7 @@
 #include "converter/segments.h"
 
 namespace mozc {
+class UserDataManagerInterface;
 
 namespace composer {
   class Composer;
@@ -59,10 +60,34 @@ class ConverterInterface {
   virtual bool StartPrediction(Segments *segments,
                                const string &key) const = 0;
 
+  // Start prediction with composer.
+  virtual bool StartPredictionWithComposer(
+      Segments *segments, const composer::Composer *composer) const = 0;
+
   // Start suggestion with key (request_type = SUGGESTION)
   virtual bool StartSuggestion(Segments *segments,
                                const string &key) const = 0;
 
+  // Start suggestion with composer.
+  virtual bool StartSuggestionWithComposer(
+      Segments *segments, const composer::Composer *composer) const = 0;
+
+  // Start prediction with key (request_type = PARTIAL_PREDICTION)
+  virtual bool StartPartialPrediction(Segments *segments,
+                                      const string &key) const = 0;
+
+  // Start prediction with composer (request_type = PARTIAL_PREDICTION)
+  virtual bool StartPartialPredictionWithComposer(
+      Segments *segments, const composer::Composer *composer) const = 0;
+
+  // Start suggestion with key (request_type = PARTIAL_SUGGESTION)
+  virtual bool StartPartialSuggestion(Segments *segments,
+                                      const string &key) const = 0;
+
+  // Start suggestion with composer (request_type = PARTIAL_SUGGESTION)
+  virtual bool StartPartialSuggestionWithComposer(
+      Segments *segments, const composer::Composer *composer) const = 0;
+
   // Finish conversion.
   // Segments are cleared. Context is not clreared
   virtual bool FinishConversion(Segments *segments) const = 0;
@@ -88,8 +113,23 @@ class ConverterInterface {
   // Commit candidate
   virtual bool CommitSegmentValue(Segments *segments,
                                   size_t segment_index,
-                                  int    candidate_index) const = 0;
-
+                                  int candidate_index) const = 0;
+  // Commit candidate for partial suggestion.
+  // current_segment_key : key for submitted segment.
+  // new_segment_key : key for newly inserted segment.
+  // Example:
+  //   If the preedit is "いれた|てのおちゃ",
+  //   |current_segment_key| is "いれた" and
+  //   |new_segment_key| is "てのおちゃ".
+  //   After calling this method, the segments will contain following segments.
+  //   - {key_ : "いれた",  segment_type_ : SUBMITTED}
+  //   - {key_ : "てのおちゃ", segment_type_ : FREE}
+  virtual bool CommitPartialSuggestionSegmentValue(
+      Segments *segments,
+      size_t segment_index,
+      int candidate_index,
+      const string &current_segment_key,
+      const string &new_segment_key) const = 0;
   // Focus the candidate.
   // This method is mainly called when user puts SPACE key
   // and changes the focused candidate.
@@ -125,22 +165,7 @@ class ConverterInterface {
                              const uint8 *new_size_array,
                              size_t array_size) const = 0;
 
-  // Sync mutable user data to local file system.
-  virtual bool Sync() const = 0;
-
-  // Reload mutable data from local file system.
-  virtual bool Reload() const = 0;
-
-  // TODO(taku): Remove below methods as they are too specific.
-
-  // clear user history data
-  virtual bool ClearUserHistory() const = 0;
-
-  // clear user prediction data
-  virtual bool ClearUserPrediction() const = 0;
-
-  // clear unused user prediction data
-  virtual bool ClearUnusedUserPrediction() const = 0;
+  virtual UserDataManagerInterface *GetUserDataManager() = 0;
 
  protected:
   virtual ~ConverterInterface() {}
