@@ -102,23 +102,24 @@ TEST_F(ConverterMockTest, CopySegment) {
   EXPECT_EQ("TestT13N", seg.meta_candidate(0).value);
 }
 
-TEST_F(ConverterMockTest, SetStartConvert) {
+TEST_F(ConverterMockTest, SetStartConversion) {
   ConverterInterface *converter = ConverterFactory::GetConverter();
 
   Segments output, expect;
-  SetSegments(&expect, "StartConvert");
+  SetSegments(&expect, "StartConversion");
   GetMock()->SetStartConversion(&expect, true);
   EXPECT_TRUE(converter->StartConversion(&output, "dummy"));
   EXPECT_EQ(expect.DebugString(), output.DebugString());
 }
 
-TEST_F(ConverterMockTest, SetStartConvertWithComposer) {
+TEST_F(ConverterMockTest, SetStartConversionWithComposer) {
   ConverterInterface *converter = ConverterFactory::GetConverter();
 
   Segments output, expect;
-  SetSegments(&expect, "StartConvertWithComposer");
+  SetSegments(&expect, "StartConversionWithComposer");
   GetMock()->SetStartConversionWithComposer(&expect, true);
-  EXPECT_TRUE(converter->StartConversionWithComposer(&output, NULL));
+  composer::Composer dummy_composer;
+  EXPECT_TRUE(converter->StartConversionWithComposer(&output, &dummy_composer));
   EXPECT_EQ(expect.DebugString(), output.DebugString());
 }
 
@@ -142,6 +143,17 @@ TEST_F(ConverterMockTest, SetStartPrediction) {
   EXPECT_EQ(expect.DebugString(), output.DebugString());
 }
 
+TEST_F(ConverterMockTest, SetStartPredictionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments output, expect;
+  SetSegments(&expect, "StartPredictionWithComposer");
+  GetMock()->SetStartPredictionWithComposer(&expect, true);
+  composer::Composer dummy_composer;
+  EXPECT_TRUE(converter->StartPredictionWithComposer(&output, &dummy_composer));
+  EXPECT_EQ(expect.DebugString(), output.DebugString());
+}
+
 TEST_F(ConverterMockTest, SetStartSuggestion) {
   ConverterInterface *converter = ConverterFactory::GetConverter();
 
@@ -152,6 +164,61 @@ TEST_F(ConverterMockTest, SetStartSuggestion) {
   EXPECT_EQ(expect.DebugString(), output.DebugString());
 }
 
+TEST_F(ConverterMockTest, SetStartSuggestionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments output, expect;
+  SetSegments(&expect, "StartSuggestionWithComposer");
+  GetMock()->SetStartSuggestionWithComposer(&expect, true);
+  composer::Composer dummy_composer;
+  EXPECT_TRUE(converter->StartSuggestionWithComposer(&output, &dummy_composer));
+  EXPECT_EQ(expect.DebugString(), output.DebugString());
+}
+
+TEST_F(ConverterMockTest, SetStartPartialPrediction) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments output, expect;
+  SetSegments(&expect, "StartPartialPrediction");
+  GetMock()->SetStartPartialPrediction(&expect, true);
+  EXPECT_TRUE(converter->StartPartialPrediction(&output, "dummy"));
+  EXPECT_EQ(expect.DebugString(), output.DebugString());
+}
+
+TEST_F(ConverterMockTest, SetStartPartialPredictionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments output, expect;
+  SetSegments(&expect, "StartPartialPredictionWithComposer");
+  GetMock()->SetStartPartialPredictionWithComposer(&expect, true);
+  composer::Composer dummy_composer;
+  EXPECT_TRUE(converter->StartPartialPredictionWithComposer(&output,
+                                                            &dummy_composer));
+  EXPECT_EQ(expect.DebugString(), output.DebugString());
+}
+
+TEST_F(ConverterMockTest, SetStartPartialSuggestion) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments output, expect;
+  SetSegments(&expect, "StartPartialSuggestion");
+  GetMock()->SetStartPartialSuggestion(&expect, true);
+  EXPECT_TRUE(converter->StartPartialSuggestion(&output, "dummy"));
+  EXPECT_EQ(expect.DebugString(), output.DebugString());
+}
+
+TEST_F(ConverterMockTest, SetStartPartialSuggestionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments output, expect;
+  SetSegments(&expect, "StartPartialSuggestionWithComposer");
+  GetMock()->SetStartPartialSuggestionWithComposer(&expect, true);
+  composer::Composer dummy_composer;
+  EXPECT_TRUE(converter->StartPartialSuggestionWithComposer(&output,
+                                                            &dummy_composer));
+  EXPECT_EQ(expect.DebugString(), output.DebugString());
+}
+
 TEST_F(ConverterMockTest, SetFinishConversion) {
   ConverterInterface *converter = ConverterFactory::GetConverter();
 
@@ -243,47 +310,6 @@ TEST_F(ConverterMockTest, SetResizeSegment2) {
                                        size_array, arraysize(size_array)));
   EXPECT_EQ(expect.DebugString(), output.DebugString());
 }
-
-TEST_F(ConverterMockTest, SetSync) {
-  ConverterInterface *converter = ConverterFactory::GetConverter();
-
-  GetMock()->SetSync(true);
-  EXPECT_TRUE(converter->Sync());
-
-  GetMock()->SetSync(false);
-  EXPECT_FALSE(converter->Sync());
-}
-
-TEST_F(ConverterMockTest, SetReload) {
-  ConverterInterface *converter = ConverterFactory::GetConverter();
-
-  GetMock()->SetReload(true);
-  EXPECT_TRUE(converter->Reload());
-
-  GetMock()->SetReload(false);
-  EXPECT_FALSE(converter->Reload());
-}
-
-TEST_F(ConverterMockTest, SetClearUserHistory) {
-  ConverterInterface *converter = ConverterFactory::GetConverter();
-
-  GetMock()->SetClearUserHistory(true);
-  EXPECT_TRUE(converter->ClearUserHistory());
-
-  GetMock()->SetClearUserHistory(false);
-  EXPECT_FALSE(converter->ClearUserHistory());
-}
-
-TEST_F(ConverterMockTest, SetClearUserPrediction) {
-  ConverterInterface *converter = ConverterFactory::GetConverter();
-
-  GetMock()->SetClearUserPrediction(true);
-  EXPECT_TRUE(converter->ClearUserPrediction());
-
-  GetMock()->SetClearUserPrediction(false);
-  EXPECT_FALSE(converter->ClearUserPrediction());
-}
-
 TEST_F(ConverterMockTest, GetStartConversion) {
   ConverterInterface *converter = ConverterFactory::GetConverter();
 
@@ -356,6 +382,24 @@ TEST_F(ConverterMockTest, GetStartPrediction) {
   EXPECT_EQ(input_key, last_key);
 }
 
+TEST_F(ConverterMockTest, GetStartPredictionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments input;
+  composer::Composer input_composer;
+  SetSegments(&input, "StartPredictionWithComposer");
+  const string input_str = input.DebugString();
+  converter->StartPredictionWithComposer(&input, &input_composer);
+
+  Segments last_segment;
+  const composer::Composer *last_composer;
+  GetMock()->GetStartPredictionWithComposer(&last_segment, &last_composer);
+  const string last_segment_str = last_segment.DebugString();
+
+  EXPECT_EQ(input_str, last_segment_str);
+  EXPECT_EQ(&input_composer, last_composer);
+}
+
 TEST_F(ConverterMockTest, GetStartSuggestion) {
   ConverterInterface *converter = ConverterFactory::GetConverter();
 
@@ -374,6 +418,98 @@ TEST_F(ConverterMockTest, GetStartSuggestion) {
   EXPECT_EQ(input_key, last_key);
 }
 
+TEST_F(ConverterMockTest, GetStartSuggestionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments input;
+  composer::Composer input_composer;
+  SetSegments(&input, "StartSuggestionWithComposer");
+  const string input_str = input.DebugString();
+  converter->StartSuggestionWithComposer(&input, &input_composer);
+
+  Segments last_segment;
+  const composer::Composer *last_composer;
+  GetMock()->GetStartSuggestionWithComposer(&last_segment, &last_composer);
+  const string last_segment_str = last_segment.DebugString();
+
+  EXPECT_EQ(input_str, last_segment_str);
+  EXPECT_EQ(&input_composer, last_composer);
+}
+
+TEST_F(ConverterMockTest, GetStartPartialPrediction) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments input;
+  const string input_key = "Key";
+  SetSegments(&input, "StartPartialPrediction");
+  const string input_str = input.DebugString();
+  converter->StartPartialPrediction(&input, input_key);
+
+  Segments last_segment;
+  string last_key;
+  GetMock()->GetStartPartialPrediction(&last_segment, &last_key);
+  const string last_segment_str = last_segment.DebugString();
+
+  EXPECT_EQ(input_str, last_segment_str);
+  EXPECT_EQ(input_key, last_key);
+}
+
+TEST_F(ConverterMockTest, GetStartPartialPredictionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments input;
+  composer::Composer input_composer;
+  SetSegments(&input, "StartPartialPredictionWithComposer");
+  const string input_str = input.DebugString();
+  converter->StartPartialPredictionWithComposer(&input, &input_composer);
+
+  Segments last_segment;
+  const composer::Composer *last_composer;
+  GetMock()->GetStartPartialPredictionWithComposer(&last_segment,
+                                                   &last_composer);
+  const string last_segment_str = last_segment.DebugString();
+
+  EXPECT_EQ(input_str, last_segment_str);
+  EXPECT_EQ(&input_composer, last_composer);
+}
+
+TEST_F(ConverterMockTest, GetStartPartialSuggestion) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments input;
+  const string input_key = "Key";
+  SetSegments(&input, "StartPartialSuggestion");
+  const string input_str = input.DebugString();
+  converter->StartPartialSuggestion(&input, input_key);
+
+  Segments last_segment;
+  string last_key;
+  GetMock()->GetStartPartialSuggestion(&last_segment, &last_key);
+  const string last_segment_str = last_segment.DebugString();
+
+  EXPECT_EQ(input_str, last_segment_str);
+  EXPECT_EQ(input_key, last_key);
+}
+
+TEST_F(ConverterMockTest, GetStartPartialSuggestionWithComposer) {
+  ConverterInterface *converter = ConverterFactory::GetConverter();
+
+  Segments input;
+  composer::Composer input_composer;
+  SetSegments(&input, "StartPartialSuggestionWithComposer");
+  const string input_str = input.DebugString();
+  converter->StartPartialSuggestionWithComposer(&input, &input_composer);
+
+  Segments last_segment;
+  const composer::Composer *last_composer;
+  GetMock()->GetStartPartialSuggestionWithComposer(&last_segment,
+                                                   &last_composer);
+  const string last_segment_str = last_segment.DebugString();
+
+  EXPECT_EQ(input_str, last_segment_str);
+  EXPECT_EQ(&input_composer, last_composer);
+}
+
 TEST_F(ConverterMockTest, GetFinishConversion) {
   ConverterInterface *converter = ConverterFactory::GetConverter();
 
