@@ -1,4 +1,4 @@
-// Copyright 2010, Google Inc.
+// Copyright 2010-2011, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -49,8 +49,10 @@ class UserDictionary : public DictionaryInterface {
 
   virtual Node *LookupPredictive(const char *str, int size,
                                  NodeAllocatorInterface *allocator) const;
-  virtual Node *LookupPrefix(const char *str, int size,
-                             NodeAllocatorInterface *allocator) const;
+  virtual Node *LookupPrefixWithLimit(
+      const char *str, int size,
+      const Limit &limit,
+      NodeAllocatorInterface *allocator) const;
   virtual Node *LookupReverse(const char *str, int size,
                               NodeAllocatorInterface *allocator) const;
 
@@ -58,9 +60,11 @@ class UserDictionary : public DictionaryInterface {
   // mainly for unittesting
   bool Load(const UserDictionaryStorage &storage);
 
-  // Reload
   bool Reload();
 
+  // Reload synchronously.
+  bool SyncReload();
+
   // Reload dictionary asynchronously
   bool AsyncReload();
 
