@@ -435,6 +435,50 @@ TEST(UserDictionaryImporter, ImportFromIteratorNormalTest) {
   }
 }
 
+TEST(UserDictionaryImporter, ImportFromIteratorSyncableTest) {
+  TestInputIterator iter;
+  UserDictionaryStorage::UserDictionary user_dic;
+
+  // Target is sync dictionary.
+  user_dic.set_syncable(true);
+  static const size_t kSize[] = { 10, 100, 1000, 5000, 12000 };
+  for (size_t i = 0; i < arraysize(kSize); ++i) {
+    vector<UserDictionaryStorage::UserDictionaryEntry> entries;
+    for (size_t j = 0; j < kSize[i]; ++j) {
+      UserDictionaryStorage::UserDictionaryEntry entry;
+      const string key = "key" + Util::SimpleItoa(j);
+      const string value = "value" + Util::SimpleItoa(j);
+      entry.set_key(key);
+      entry.set_value(value);
+      // entry.set_pos("名詞");
+      entry.set_pos("\xE5\x90\x8D\xE8\xA9\x9E");
+      entries.push_back(entry);
+    }
+
+    iter.set_available(true);
+    iter.set_entries(&entries);
+
+    // In case of sync dictionary, the upper limit is
+    // max_sync_entry_size instead of max_entry_size.
+    if (kSize[i] <= UserDictionaryStorage::max_sync_entry_size()) {
+      EXPECT_EQ(UserDictionaryImporter::IMPORT_NO_ERROR,
+                UserDictionaryImporter::ImportFromIterator(
+                    &iter, &user_dic));
+    } else {
+      EXPECT_EQ(UserDictionaryImporter::IMPORT_TOO_MANY_WORDS,
+                UserDictionaryImporter::ImportFromIterator(
+                    &iter, &user_dic));
+    }
+
+    const size_t size = min(UserDictionaryStorage::max_sync_entry_size(),
+                            kSize[i]);
+    EXPECT_EQ(size, user_dic.entries_size());
+    for (size_t j = 0; j < size; ++j) {
+      EXPECT_EQ(entries[j].DebugString(),
+                user_dic.entries(j).DebugString());
+    }
+  }
+}
 
 TEST(UserDictionaryImporter, ImportFromIteratorInvalidEntriesTest) {
   TestInputIterator iter;
