@@ -13,44 +13,52 @@
         <source>OK</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="about_dialog.ui" line="85"/>
-        <source>You are using the latest version</source>
-        <translation>最新版のMozcです</translation>
-    </message>
-    <message>
-        <location filename="about_dialog.ui" line="105"/>
-        <source>(0.0.0.0)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message utf8="true">
-        <location filename="about_dialog.ui" line="145"/>
+        <location filename="about_dialog.ui" line="80"/>
         <source>Copyright © 2011 Google Inc. All Rights Reserved.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="about_dialog.ui" line="160"/>
+        <location filename="about_dialog.ui" line="95"/>
         <source>&lt;html&gt;&lt;body&gt;Mozc is made possible by &lt;a href=&quot;file://credits_en.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;open source software&lt;/span&gt;&lt;/a&gt;.&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;body&gt;Mozcは&lt;a href=&quot;file://credits_ja.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;オープンソースソフトウェア&lt;/span&gt;&lt;/a&gt;を利用しています。&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="about_dialog.ui" line="198"/>
+        <location filename="about_dialog.ui" line="133"/>
         <source>&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;http://code.google.com/p/mozc/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;product information&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished">&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;http://code.google.com/p/mozc/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;製品情報&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
+    <message>
+        <location filename="about_dialog.ui" line="165"/>
+        <source>Update</source>
+        <translation>アップデート</translation>
+    </message>
     <message>
         <source>&lt;html&gt;&lt;body&gt;Google &lt;a href=&quot;file://privacy_en.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;privacy policy&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="obsolete">&lt;html&gt;&lt;body&gt;Google &lt;a href=&quot;file://privacy_ja.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;プライバシー ポリシー&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="about_dialog.ui" line="239"/>
+        <location filename="about_dialog.ui" line="193"/>
         <source>Mozc</source>
         <translation>Mozc</translation>
     </message>
     <message>
-        <location filename="about_dialog.ui" line="262"/>
+        <location filename="about_dialog.ui" line="216"/>
         <source>0.0.0.0</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>mozc::gui::AboutDialog</name>
+    <message>
+        <location filename="about_dialog.cc" line="135"/>
+        <source>New version is available</source>
+        <translation>新しい Mozcがあります</translation>
+    </message>
+    <message>
+        <location filename="about_dialog.cc" line="146"/>
+        <source>You are using the latest version</source>
+        <translation>最新版の Mozcです</translation>
+    </message>
+</context>
 </TS>
