@@ -1,4 +1,4 @@
-// Copyright 2010, Google Inc.
+// Copyright 2010-2011, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -61,6 +61,7 @@
 #include "base/version.h"
 #include "ipc/ipc.h"
 #include "ipc/ipc.pb.h"
+#include "languages/global_language_spec.h"
 
 namespace mozc {
 namespace {
@@ -77,8 +78,16 @@ string GetIPCKeyFileName(const string &name) {
   string basename = ".";    // hidden file
 #endif
 
-  basename += name;
-  basename += ".ipc";   // this is the extension part.
+  basename.append(name);
+#ifdef OS_LINUX
+  // TODO(nona): Support multi platform
+  const language::LanguageDependentSpecInterface *lang_spec =
+      language::GlobalLanguageSpec::GetLanguageDependentSpec();
+
+  basename.append("_");
+  basename.append(lang_spec->GetLanguageName());
+#endif
+  basename.append(".ipc");   // this is the extension part.
 
   return Util::JoinPath(Util::GetUserProfileDirectory(), basename);
 }
