@@ -1,4 +1,4 @@
-// Copyright 2010, Google Inc.
+// Copyright 2010-2011, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,8 @@
 #include "base/util.h"
 #include "base/thread.h"
 #include "ipc/ipc_path_manager.h"
+#include "languages/global_language_spec.h"
+#include "languages/japanese/lang_dep_spec.h"
 #include "testing/base/public/gunit.h"
 
 DECLARE_string(test_tmpdir);
@@ -76,9 +78,23 @@ class BatchGetPathNameThread : public Thread {
 };
 }  // anonymous namespace
 
-TEST(IPCPathManagerTest, IPCPathManagerTest) {
-  mozc::Util::SetUserProfileDirectory(FLAGS_test_tmpdir);
+class IPCPathManagerTest : public ::testing::Test {
+ protected:
+  virtual void SetUp() {
+    mozc::Util::SetUserProfileDirectory(FLAGS_test_tmpdir);
+    mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(
+        &lang_dep_spec_);
+  }
 
+  virtual void TearDown() {
+    mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(NULL);
+  }
+
+ private:
+  mozc::japanese::LangDepSpecJapanese lang_dep_spec_;
+};
+
+TEST_F(IPCPathManagerTest, IPCPathManagerTest) {
   CreateThread t;
   t.Start();
   Util::Sleep(1000);
@@ -101,7 +117,7 @@ TEST(IPCPathManagerTest, IPCPathManagerTest) {
 
 // Test the thread-safeness of GetPathName() and
 // GetIPCPathManager
-TEST(IPCPathManagerTest, IPCPathManagerBatchTest) {
+TEST_F(IPCPathManagerTest, IPCPathManagerBatchTest) {
   vector<BatchGetPathNameThread> threads(8192);
   for (size_t i = 0; i < threads.size(); ++i) {
     threads[i].Start();
@@ -111,7 +127,7 @@ TEST(IPCPathManagerTest, IPCPathManagerBatchTest) {
   }
 }
 
-TEST(IPCPathManagerTest, ReloadTest) {
+TEST_F(IPCPathManagerTest, ReloadTest) {
   // We have only mock implementations for Windows, so no test should be run.
 #ifndef OS_WINDOWS
   mozc::IPCPathManager *manager =
