@@ -37,12 +37,13 @@
 
 namespace mozc {
 namespace client {
-class SessionInterface;
+class ClientInterface;
 }  // namespace mozc::client
 
 namespace commands {
 class Output;
 class RendererCommand;
+class SessionCommand;
 }
 
 namespace renderer {
@@ -106,20 +107,22 @@ class RendererInterface;
   // |rendererCommand_| stores the command sent to |candidateController_|
   mozc::commands::RendererCommand *rendererCommand_;
 
-  // |session_| manages connection to the mozc server.
-  mozc::client::SessionInterface *session_;
+  // |mozcClient_| manages connection to the mozc server.
+  mozc::client::ClientInterface *mozcClient_;
 
-  // |server_| holds the reference to GoogleJapaneseInputServer.
-  id<ServerCallback> server_;
+  // |imkServer_| holds the reference to GoogleJapaneseInputServer.
+  id<ServerCallback> imkServer_;
 
   // |menu_| is the NSMenu to be shown in the pulldown menu-list of
   // the IME.
   IBOutlet NSMenu *menu_;
 }
 
-// candidateClicked: is called when the user clicks a candidate item
-// in candidate windows.
-- (void)candidateClicked:(int)id;
+// sendCommand: is called to send SessionCommand to the server
+// from the renderer, when the user clicks a candidate item
+// in candidate windows or when the renderer sends the usage stats
+// event information.
+- (void)sendCommand:(mozc::commands::SessionCommand&)command;
 
 // reconversionClicked: is called when the user clicks "Reconversion"
 // menu item.
