@@ -34,8 +34,9 @@
 #include <sstream>
 
 #include "base/util.h"
-#include "client/session_interface.h"
-#include "renderer/coordinates.h"
+#include "base/coordinates.h"
+#include "client/client_interface.h"
+#include "renderer/renderer_style_handler.h"
 #include "renderer/table_layout.h"
 #include "renderer/win_resource.h"
 #include "renderer/win32/text_renderer.h"
@@ -56,6 +57,7 @@ using WTL::CRect;
 using WTL::CSize;
 
 namespace {
+
 // 96 DPI is the default DPI in Windows.
 const int kDefaultDPI = 96;
 
@@ -96,11 +98,14 @@ const COLORREF kFooterBottomColor = RGB(0xee, 0xee, 0xee);
 // ------------------------------------------------------------------------
 // Utility functions
 // ------------------------------------------------------------------------
+WTL::CRect ToCRect(const Rect &rect) {
+  return WTL::CRect(rect.Left(), rect.Top(), rect.Right(), rect.Bottom());
+}
 
 // Returns the smallest index of the given candidate list which satisfies
 // candidates.candidate(i) == |candidate_index|.
 // This function returns the size of the given candidate list when there
-// aren't any candidates satifying the above condition.
+// aren't any candidates satisfying the above condition.
 int GetCandidateArrayIndexByCandidateIndex(
     const commands::Candidates &candidates,
     int candidate_index) {
@@ -141,7 +146,7 @@ string GetIndexGuideString(const commands::Candidates &candidates) {
 // Returns the smallest index of the given candidate list which satisfies
 // |candidates.focused_index| == |candidates.candidate(i).index()|.
 // This function returns the size of the given candidate list when there
-// aren't any candidates satifying the above condition.
+// aren't any candidates satisfying the above condition.
 int GetFocusedArrayIndex(const commands::Candidates &candidates) {
   const int kInvalidIndex = candidates.candidate_size();
 
@@ -238,24 +243,21 @@ CandidateWindow::CandidateWindow()
       text_renderer_(new TextRenderer),
       table_layout_(new TableLayout),
       send_command_interface_(NULL) {
-  CDC desktop_dc(::GetDC(NULL));
-  const int dpi_x = desktop_dc.GetDeviceCaps(LOGPIXELSX);
-  const int dpi_y = desktop_dc.GetDeviceCaps(LOGPIXELSY);
+  double scale_factor_x = 1.0;
+  double scale_factor_y = 1.0;
+  RendererStyleHandler::GetDPIScalingFactor(&scale_factor_x,
+                                            &scale_factor_y);
 
   // If DPI is not default value, re-calculate the size based on the DPI.
   if (!footer_logo_.IsNull()) {
     CSize size;
     footer_logo_.GetSize(size);
-
-    if (dpi_x != kDefaultDPI || dpi_y != kDefaultDPI) {
-      size.cx = ::MulDiv(size.cx, dpi_x, kDefaultDPI);
-      size.cy = ::MulDiv(size.cy, dpi_y, kDefaultDPI);
-    }
-
-    footer_logo_display_size_ = Size(size);
+    size.cx *= scale_factor_x;
+    size.cy *= scale_factor_y;
+    footer_logo_display_size_ = Size(size.cx, size.cy);
   }
 
-  indicator_width_ = ::MulDiv(kIndicatorWidthInDefaultDPI, dpi_x, kDefaultDPI);
+  indicator_width_ = kIndicatorWidthInDefaultDPI * scale_factor_x;
 
   text_renderer_->Init();
 }
@@ -292,6 +294,13 @@ BOOL CandidateWindow::OnEraseBkgnd(CDCHandle dc) {
   return TRUE;
 }
 
+void CandidateWindow::OnGetMinMaxInfo(MINMAXINFO *min_max_info) {
+  // Do not restrict the window size in case the candidate window must be
+  // very small size.
+  min_max_info->ptMinTrackSize.x = 1;
+  min_max_info->ptMinTrackSize.y = 1;
+  SetMsgHandled(TRUE);
+}
 
 void CandidateWindow::HandleMouseEvent(
     UINT nFlags, const WTL::CPoint &point, bool close_candidatewindow) {
@@ -306,7 +315,7 @@ void CandidateWindow::HandleMouseEvent(
     const commands::Candidates::Candidate &candidate
         = candidates_->candidate(i);
 
-    const CRect rect = table_layout_->GetRowRect(i).ToCRect();
+    const CRect rect = ToCRect(table_layout_->GetRowRect(i));
     if (rect.PtInRect(point)) {
       commands::SessionCommand command;
       if (close_candidatewindow) {
@@ -396,6 +405,7 @@ void CandidateWindow::DoPaint(CDCHandle dc) {
   DrawShortcutBackground(dc);
   DrawSelectedRect(dc);
   DrawCells(dc);
+  DrawInformationIcon(dc);
   DrawVScrollBar(dc);
   DrawFooter(dc);
   DrawFrame(dc);
@@ -606,9 +616,9 @@ Rect CandidateWindow::GetSelectionRectInScreenCord() const {
     const commands::Candidates::Candidate &candidate =
         candidates_->candidate(focused_array_index);
 
-    CRect rect = table_layout_->GetRowRect(focused_array_index).ToCRect();
+    CRect rect = ToCRect(table_layout_->GetRowRect(focused_array_index));
     ClientToScreen(&rect);
-    return Rect(rect);
+    return Rect(rect.left, rect.top, rect.Width(), rect.Height());
   }
 
   return Rect();
@@ -664,14 +674,14 @@ void CandidateWindow::DrawVScrollBar(CDCHandle dc) {
     const int end_index =
         candidates_->candidate(candidates_in_page - 1).index();
 
-    const CRect background_crect = vscroll_rect.ToCRect();
+    const CRect background_crect = ToCRect(vscroll_rect);
     dc.FillSolidRect(&background_crect, kIndicatorBackgroundColor);
 
-    const mozc::renderer::Rect &indicator_rect =
+    const mozc::Rect &indicator_rect =
         table_layout_->GetVScrollIndicatorRect(
             begin_index, end_index, candidates_total);
 
-    const CRect indicator_crect = indicator_rect.ToCRect();
+    const CRect indicator_crect = ToCRect(indicator_rect);
     dc.FillSolidRect(&indicator_crect, kIndicatorColor);
   }
 }
@@ -689,7 +699,7 @@ void CandidateWindow::DrawShortcutBackground(CDCHandle dc) {
       const int width = shortcut_colmun_rect.Right() - row_rect.Left();
       shortcut_colmun_rect.origin.x = row_rect.Left();
       shortcut_colmun_rect.size.width = width;
-      const CRect shortcut_colmun_crect = shortcut_colmun_rect.ToCRect();
+      const CRect shortcut_colmun_crect = ToCRect(shortcut_colmun_rect);
       dc.FillSolidRect(&shortcut_colmun_crect, kShortcutBackgroundColor);
     }
   }
@@ -822,7 +832,7 @@ void CandidateWindow::DrawSelectedRect(CDCHandle dc) {
         = candidates_->candidate(focused_array_index);
 
     const CRect selected_rect =
-        table_layout_->GetRowRect(focused_array_index).ToCRect();
+        ToCRect(table_layout_->GetRowRect(focused_array_index));
     dc.FillSolidRect(&selected_rect, kSelectedRowBackgroundColor);
 
     dc.SetDCBrushColor(kSelectedRowFrameColor);
@@ -831,15 +841,36 @@ void CandidateWindow::DrawSelectedRect(CDCHandle dc) {
   }
 }
 
+void CandidateWindow::DrawInformationIcon(CDCHandle dc) {
+  DCHECK(table_layout_->IsLayoutFrozen()) << "Table layout is not frozen.";
+  double scale_factor_x = 1.0;
+  double scale_factor_y = 1.0;
+  RendererStyleHandler::GetDPIScalingFactor(&scale_factor_x,
+                                            &scale_factor_y);
+  for (size_t i = 0; i < candidates_->candidate_size(); ++i) {
+    if (candidates_->candidate(i).has_information_id()) {
+      CRect rect = ToCRect(table_layout_->GetRowRect(i));
+      rect.left = rect.right - (6.0 * scale_factor_x);
+      rect.right = rect.right - (2.0 * scale_factor_x);
+      rect.top += (2.0 * scale_factor_y);
+      rect.bottom -= (2.0 * scale_factor_y);
+      dc.FillSolidRect(&rect, kIndicatorColor);
+      dc.SetDCBrushColor(kIndicatorColor);
+      dc.FrameRect(&rect,
+                   static_cast<HBRUSH>(GetStockObject(DC_BRUSH)));
+    }
+  }
+}
+
 void CandidateWindow::DrawBackground(CDCHandle dc) {
   const Rect client_rect(Point(0, 0), table_layout_->GetTotalSize());
-  const CRect client_crect = client_rect.ToCRect();
+  const CRect client_crect = ToCRect(client_rect);
   dc.FillSolidRect(&client_crect, kDefaultBackgroundColor);
 }
 
 void CandidateWindow::DrawFrame(CDCHandle dc) {
   const Rect client_rect(Point(0, 0), table_layout_->GetTotalSize());
-  const CRect client_crect = client_rect.ToCRect();
+  const CRect client_crect = ToCRect(client_rect);
 
   // DC brush is available in Windows 2000 and later.
   dc.SetDCBrushColor(kFrameColor);
