@@ -30,12 +30,12 @@
 #include <string>
 
 #include "base/util.h"
+#include "config/config_handler.h"
+#include "config/config.pb.h"
 #include "converter/segments.h"
 #include "converter/character_form_manager.h"
 #include "rewriter/variants_rewriter.h"
 #include "testing/base/public/gunit.h"
-#include "session/config_handler.h"
-#include "session/config.pb.h"
 
 DECLARE_string(test_tmpdir);
 
@@ -44,11 +44,34 @@ namespace mozc {
 class VariantsRewriterTest : public testing::Test {
  protected:
   virtual void SetUp() {
+    Reset();
+  }
+
+  virtual void TearDown() {
+    Reset();
+  }
+
+  void Reset() {
     Util::SetUserProfileDirectory(FLAGS_test_tmpdir);
     config::Config config;
     config::ConfigHandler::GetDefaultConfig(&config);
     config::ConfigHandler::SetConfig(config);
     CharacterFormManager::GetCharacterFormManager()->SetDefaultRule();
+    CharacterFormManager::GetCharacterFormManager()->ClearHistory();
+  }
+
+  void InitSegmentsForAlphabetRewrite(const string &value,
+                                      Segments *segments) const {
+    Segment *segment = segments->push_back_segment();
+    CHECK(segment);
+    segment->set_key(value);
+    Segment::Candidate *candidate = segment->add_candidate();
+    CHECK(candidate);
+    candidate->Init();
+    candidate->key = value;
+    candidate->content_key = value;
+    candidate->value = value;
+    candidate->content_value = value;
   }
 };
 
@@ -355,7 +378,8 @@ TEST_F(VariantsRewriterTest, SetDescriptionForCandidate) {
     candidate.content_value = candidate.value;
     candidate.content_key = "!@#";
     VariantsRewriter::SetDescriptionForCandidate(&candidate);
-    EXPECT_EQ("[半]", candidate.description);
+    // "[半]"
+    EXPECT_EQ("\x5b\xe5\x8d\x8a\x5d", candidate.description);
   }
   {
     Segment::Candidate candidate;
@@ -517,4 +541,140 @@ TEST_F(VariantsRewriterTest, SetDescriptionForPrediction) {
               "\xE5\xAD\x98\xE6\x96\x87\xE5\xAD\x97>", candidate.description);
   }
 }
+
+TEST_F(VariantsRewriterTest, RewriteForConversion) {
+  CharacterFormManager *character_form_manager =
+      CharacterFormManager::GetCharacterFormManager();
+  VariantsRewriter rewriter;
+  {
+    Segments segments;
+    segments.set_request_type(Segments::CONVERSION);
+    {
+      Segment *segment = segments.push_back_segment();
+      segment->set_key("abc");
+      Segment::Candidate *candidate = segment->add_candidate();
+      candidate->Init();
+      candidate->key = "abc";
+      candidate->content_key = "abc";
+      candidate->value = "abc";
+      candidate->content_value = "abc";
+    }
+    EXPECT_TRUE(rewriter.Rewrite(&segments));
+    EXPECT_EQ(1, segments.segments_size());
+    EXPECT_EQ(2, segments.segment(0).candidates_size());
+
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              character_form_manager->GetConversionCharacterForm("abc"));
+
+    // "ａｂｃ"
+    EXPECT_EQ("\xef\xbd\x81\xef\xbd\x82\xef\xbd\x83",
+              segments.segment(0).candidate(0).value);
+    EXPECT_EQ("abc", segments.segment(0).candidate(1).value);
+  }
+  {
+    character_form_manager->SetCharacterForm("abc", config::Config::HALF_WIDTH);
+    Segments segments;
+    segments.set_request_type(Segments::CONVERSION);
+    {
+      Segment *segment = segments.push_back_segment();
+      segment->set_key("abc");
+      Segment::Candidate *candidate = segment->add_candidate();
+      candidate->Init();
+      candidate->key = "abc";
+      candidate->content_key = "abc";
+      candidate->value = "abc";
+      candidate->content_value = "abc";
+    }
+    EXPECT_TRUE(rewriter.Rewrite(&segments));
+    EXPECT_EQ(1, segments.segments_size());
+    EXPECT_EQ(2, segments.segment(0).candidates_size());
+
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              character_form_manager->GetConversionCharacterForm("abc"));
+
+    EXPECT_EQ("abc", segments.segment(0).candidate(0).value);
+    // "ａｂｃ"
+    EXPECT_EQ("\xef\xbd\x81\xef\xbd\x82\xef\xbd\x83",
+              segments.segment(0).candidate(1).value);
+  }
+}
+
+TEST_F(VariantsRewriterTest, RewriteForPrediction) {
+  CharacterFormManager *character_form_manager =
+      CharacterFormManager::GetCharacterFormManager();
+  VariantsRewriter rewriter;
+  {
+    Segments segments;
+    segments.set_request_type(Segments::PREDICTION);
+    InitSegmentsForAlphabetRewrite("abc", &segments);
+    EXPECT_TRUE(rewriter.Rewrite(&segments));
+    EXPECT_EQ(1, segments.segments_size());
+    EXPECT_EQ(2, segments.segment(0).candidates_size());
+
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              character_form_manager->GetConversionCharacterForm("abc"));
+
+    // "ａｂｃ"
+    EXPECT_EQ("\xef\xbd\x81\xef\xbd\x82\xef\xbd\x83",
+              segments.segment(0).candidate(0).value);
+    EXPECT_EQ("abc", segments.segment(0).candidate(1).value);
+  }
+  {
+    character_form_manager->SetCharacterForm("abc", config::Config::HALF_WIDTH);
+    Segments segments;
+    segments.set_request_type(Segments::PREDICTION);
+    InitSegmentsForAlphabetRewrite("abc", &segments);
+    EXPECT_TRUE(rewriter.Rewrite(&segments));
+    EXPECT_EQ(1, segments.segments_size());
+    EXPECT_EQ(2, segments.segment(0).candidates_size());
+
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              character_form_manager->GetConversionCharacterForm("abc"));
+
+    EXPECT_EQ("abc", segments.segment(0).candidate(0).value);
+    // "ａｂｃ"
+    EXPECT_EQ("\xef\xbd\x81\xef\xbd\x82\xef\xbd\x83",
+              segments.segment(0).candidate(1).value);
+  }
+}
+
+TEST_F(VariantsRewriterTest, RewriteForSuggestion) {
+  CharacterFormManager *character_form_manager =
+      CharacterFormManager::GetCharacterFormManager();
+  VariantsRewriter rewriter;
+  {
+    Segments segments;
+    segments.set_request_type(Segments::SUGGESTION);
+    InitSegmentsForAlphabetRewrite("abc", &segments);
+    EXPECT_TRUE(rewriter.Rewrite(&segments));
+    EXPECT_EQ(1, segments.segments_size());
+    EXPECT_EQ(1, segments.segment(0).candidates_size());
+
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              character_form_manager->GetConversionCharacterForm("abc"));
+
+    // "ａｂｃ"
+    EXPECT_EQ("\xef\xbd\x81\xef\xbd\x82\xef\xbd\x83",
+              segments.segment(0).candidate(0).value);
+  }
+  {
+    character_form_manager->SetCharacterForm("abc", config::Config::HALF_WIDTH);
+    Segments segments;
+    segments.set_request_type(Segments::SUGGESTION);
+    InitSegmentsForAlphabetRewrite("abc", &segments);
+    EXPECT_TRUE(rewriter.Rewrite(&segments));
+    EXPECT_EQ(1, segments.segments_size());
+    EXPECT_EQ(1, segments.segment(0).candidates_size());
+
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              character_form_manager->GetConversionCharacterForm("abc"));
+
+    EXPECT_EQ("abc", segments.segment(0).candidate(0).value);
+  }
+}
+
+TEST_F(VariantsRewriterTest, Capability) {
+  VariantsRewriter rewriter;
+  EXPECT_EQ(RewriterInterface::ALL, rewriter.capability());
+}
 }  // namespace mozc
