@@ -1,4 +1,4 @@
-// Copyright 2010, Google Inc.
+// Copyright 2010-2011, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,73 +32,76 @@
 #ifndef MOZC_SESSION_SESSION_H_
 #define MOZC_SESSION_SESSION_H_
 
-#include <map>
 #include <string>
-#include <vector>
 
 #include "base/base.h"
-#include "transliteration/transliteration.h"
-#include "converter/converter_interface.h"
+#include "base/coordinates.h"
+#include "composer/composer.h"
 #include "session/commands.pb.h"
-#include "session/common.h"
-// This should be keymap_interface.h
-#include "session/internal/keymap.h"
+#include "session/session_interface.h"
+// Need to include it for "ImeContext::State".
+#include "session/internal/ime_context.h"
+#include "transliteration/transliteration.h"
+// for FRIEND_TEST()
+#include "testing/base/public/gunit_prod.h"
 
 namespace mozc {
-class ConverterInterface;
-
-namespace composer {
-class Composer;
-class Table;
-}  // namespace composer
-
-namespace keymap {
-class KeyMapManager;
-}  // namespace keymap
-
 namespace session {
-class SessionConverterInterface;
-}  // namespace session
-
-struct SessionState {
-  enum Type {
-    NONE = 0,
-    DIRECT = 1,
-    PRECOMPOSITION = 2,
-    COMPOSITION = 4,
-    CONVERSION = 8,
-  };
-};
-
-typedef map<string, commands::KeyEvent> TransformTable;
-
-class Session {
+class SessionCursorManageTest;
+class Session : public SessionInterface {
  public:
-  Session(const composer::Table *table,
-          const ConverterInterface *converter,
-          const keymap::KeyMapManager *keymap);
-  ~Session();
+  Session();
+  virtual ~Session();
 
-  bool SendKey(commands::Command *command);
+  virtual bool SendKey(commands::Command *command);
 
   // Check if the input key event will be consumed by the session.
-  bool TestSendKey(commands::Command *command);
+  virtual bool TestSendKey(commands::Command *command);
 
   // Perform the SEND_COMMAND command defined commands.proto.
-  bool SendCommand(commands::Command *command);
+  virtual bool SendCommand(commands::Command *command);
 
   bool IMEOn(commands::Command *command);
   bool IMEOff(commands::Command *command);
   bool EchoBack(commands::Command *command);
+  bool EchoBackAndClearUndoContext(commands::Command *command);
   bool DoNothing(commands::Command *command);
   // Kill itself without any finalization.  It only works on debug builds.
   bool Abort(commands::Command *command);
 
+  // Reset the composer and clear conversion segments.
+  // History segments will not be cleared.
+  // Therefore if a user commits "風"(かぜ) and Revert method is called,
+  // preedit "ひいた"  will be converted into "邪引いた".
   bool Revert(commands::Command *command);
+  // Reset the composer and clear all the segments (including history segments).
+  // Therefore preedit "ひいた"  will *not* be converted into "邪引いた"
+  // on the situation described above.
+  bool ResetContext(commands::Command *command);
 
   // Return the current status such as a composition string, input mode, etc.
   bool GetStatus(commands::Command *command);
 
+  // Fill Output::Callback with the CONVERT_REVERSE SessionCommand to
+  // ask the client to send back the SessionCommand to the server.
+  // This function is called when the key event representing the
+  // ConvertReverse keybinding is called.
+  bool RequestConvertReverse(commands::Command *command);
+
+  // Begins reverse conversion for the given session.  This function
+  // is called when the CONVERT_REVERSE SessionCommand is called.
+  bool ConvertReverse(commands::Command *command);
+
+  // Fill Output::Callback with the Undo SessionCommand to ask the
+  // client to send back the SessionCommand to the server.
+  // This function is called when the key event representing the
+  // Undo keybinding is called.
+  bool RequestUndo(commands::Command *command);
+
+  // Undo the commitment.  This function is called when the
+  // UNDO SessionCommand is called.
+  bool Undo(commands::Command *command);
+
   bool InsertSpace(commands::Command *command);
   bool InsertSpaceToggled(commands::Command *command);
   bool InsertSpaceHalfWidth(commands::Command *command);
@@ -112,6 +115,7 @@ class Session {
   bool MoveCursorLeft(commands::Command *command);
   bool MoveCursorToEnd(commands::Command *command);
   bool MoveCursorToBeginning(commands::Command *command);
+  bool MoveCursorTo(commands::Command *command);
   bool Convert(commands::Command *command);
   // Start converion not using user history.  This is used for debugging.
   bool ConvertWithoutHistory(commands::Command *command);
@@ -126,8 +130,15 @@ class Session {
   bool Commit(commands::Command *command);
   bool CommitFirstSuggestion(commands::Command *command);
 
+  // Expands suggestion candidates.
+  bool ExpandSuggestion(commands::Command *command);
+
   // Commit only the first segment.
   bool CommitSegment(commands::Command *command);
+  // Commit some characters at the head of the preedit.
+  bool CommitHead(size_t count, commands::Command *command);
+  // Commit preedit if in password mode.
+  bool CommitIfPassword(commands::Command *command);
 
   bool SetComposition(const string &composition);
 
@@ -169,6 +180,24 @@ class Session {
   bool InputModeHalfKatakana(commands::Command *command);
   bool InputModeFullASCII(commands::Command *command);
   bool InputModeHalfASCII(commands::Command *command);
+  bool InputModeSwitchKanaType(commands::Command *command);
+
+  // Specify the input field type.
+  bool SwitchInputFieldType(commands::Command *command);
+
+  // Let client launch config dialog
+  bool LaunchConfigDialog(commands::Command *command);
+
+  // Let client launch dictionary tool
+  bool LaunchDictionaryTool(commands::Command *command);
+
+  // Let client launch word register dialog
+  bool LaunchWordRegisterDialog(commands::Command *command);
+
+  // Send a command to the composer to append a special string.
+  bool SendComposerCommand(
+      const composer::Composer::InternalCommand composer_command,
+      commands::Command *command);
 
   // finalize the session.
   bool Finish(commands::Command *command);
@@ -177,49 +206,53 @@ class Session {
 
   bool ReportBug(commands::Command *command);
 
-  void ReloadConfig();
+  virtual void ReloadConfig();
 
   // Set client capability for this session.  Used by unittest.
-  void set_client_capability(const commands::Capability &capability);
+  virtual void set_client_capability(const commands::Capability &capability);
 
   // Set application information for this session.
-  void set_application_info(const commands::ApplicationInfo
-                            &application_info);
+  virtual void set_application_info(const commands::ApplicationInfo
+                                    &application_info);
 
   // Get application information
-  const commands::ApplicationInfo &application_info() const;
+  virtual const commands::ApplicationInfo &application_info() const;
 
-  uint64 create_session_time() const {
-    return create_session_time_;
-  }
+  // Return the time when this instance was created.
+  virtual uint64 create_session_time() const;
 
-  // return static_cast<uint64>(-1) (default value)
-  // if no command is executed in this session.
-  uint64 last_command_time() const {
-    return last_command_time_;
-  }
+  // return 0 (default value) if no command is executed in this session.
+  virtual uint64 last_command_time() const;
+
+  // TODO(komatsu): delete this funciton.
+  // For unittest only
+  composer::Composer *get_internal_composer_only_for_unittest();
+
+  const ImeContext &context() const;
+
+  // Update config of |context| referring |config|.
+  static void UpdateConfig(const config::Config &config, ImeContext *context);
+
+  // Set OperationPreferences on |context| by using (tentative) |config|.
+  static void UpdateOperationPreferences(const config::Config &config,
+                                         ImeContext *context);
 
  private:
-  // TODO(komatsu): Make SessionInterface abstract class and hide
-  // private functions from the upper layers.
-  uint64 create_session_time_;
-  uint64 last_command_time_;
+  FRIEND_TEST(SessionTest, OutputInitialComposition);
+  FRIEND_TEST(SessionTest, IsFullWidthInsertSpace);
+  FRIEND_TEST(SessionTest, RequestUndo);
 
-  scoped_ptr<composer::Composer> composer_;
+  scoped_ptr<ImeContext> context_;
+  scoped_ptr<ImeContext> prev_context_;
 
-  scoped_ptr<session::SessionConverterInterface> converter_;
+  void InitContext(ImeContext *context) const;
 
-  const keymap::KeyMapManager *keymap_;
-
-  SessionState::Type state_;
-  TransformTable transform_table_;
-
-  commands::Capability client_capability_;
-
-  commands::ApplicationInfo application_info_;
+  void PushUndoContext();
+  void PopUndoContext();
+  void ClearUndoContext();
 
   // Set session state to the given state and also update related status.
-  void SetSessionState(SessionState::Type state);
+  void SetSessionState(ImeContext::State state);
 
   // Return true if full width space is preferred in the current
   // situation rather than half width space.
@@ -233,6 +266,10 @@ class Session {
   // it requires the argument id.
   bool SelectCandidate(commands::Command *command);
 
+  // Calls SessionConverter::ConmmitFirstSegment() and deletes characters
+  // from the composer.
+  void CommitFirstSegmentInternal();
+
   // Set the focus to the candidate located by input.command.id.  This
   // command would not be used from SendKey but used from SendCommand
   // because it requires the argument id.  The difference from
@@ -254,6 +291,7 @@ class Session {
   void OutputMode(commands::Command *command) const;
   void OutputComposition(commands::Command *command) const;
   void OutputKey(commands::Command *command) const;
+  void OutputWindowLocation(commands::Command *command) const;
 
   bool SendKeyDirectInputState(commands::Command *command);
   bool SendKeyPrecompositionState(commands::Command *command);
@@ -264,7 +302,7 @@ class Session {
   void UpdateTime();
 
   // update preferences only affecting this session.
-  bool UpdatePreferences(commands::Command *command);
+  void UpdatePreferences(commands::Command *command);
 
   // Modify input of SendKey, TestSendKey, and SendCommand.
   void TransformInput(commands::Input *input);
@@ -280,8 +318,15 @@ class Session {
   // Expand composition if required for nested calculation.
   void ExpandCompositionForCalculator(commands::Command *command);
 
+  // Stores received caret location into caret_rectangle_.
+  bool SetCaretLocation(commands::Command *command);
+
+  // TODO(nona): Move following rectangle state to ImeContext.
+  commands::Rectangle composition_rectangle_;
+  commands::Rectangle caret_rectangle_;
   DISALLOW_COPY_AND_ASSIGN(Session);
 };
 
+}  // namespace session
 }  // namespace mozc
 #endif  // MOZC_SESSION_SESSION_H_
