@@ -1,4 +1,4 @@
-// Copyright 2010, Google Inc.
+// Copyright 2010-2011, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,8 +33,12 @@
 #define MOZC_SESSION_SESSION_CONVERTER_H_
 
 #include <string>
+#include <vector>
 
+#include "session/commands.pb.h"
 #include "session/session_converter_interface.h"
+// for FRIEND_TEST()
+#include "testing/base/public/gunit_prod.h"
 
 namespace mozc {
 namespace session {
@@ -47,19 +51,8 @@ class SessionConverter : public SessionConverterInterface {
   explicit SessionConverter(const ConverterInterface *converter);
   virtual ~SessionConverter();
 
-  // Reload the global configuration variables.
-  void ReloadConfig();
-  // Update the configuration.
-  void UpdateConfig(const config::Config &config);
-
-  typedef int States;
-  enum State {
-    NO_STATE = 0,
-    COMPOSITION = 1,
-    SUGGESTION = 2,
-    PREDICTION = 4,
-    CONVERSION = 8,
-  };
+  // Update OperationPreferences.
+  void SetOperationPreferences(const OperationPreferences &preferences);
 
   // Check if the current state is in the state bitmap.
   bool CheckState(States) const;
@@ -74,32 +67,43 @@ class SessionConverter : public SessionConverterInterface {
   const ConversionPreferences &conversion_preferences() const;
 
   // Send a conversion request to the converter.
-  bool Convert(const composer::Composer *composer);
-  bool ConvertWithPreferences(const composer::Composer *composer,
+  bool Convert(const composer::Composer &composer);
+  bool ConvertWithPreferences(const composer::Composer &composer,
                               const ConversionPreferences &preferences);
 
+  // Get reading text (e.g. from "猫" to "ねこ").
+  bool GetReadingText(const string &source_text, string *reading);
+
   // Send a transliteration request to the converter.
-  bool ConvertToTransliteration(const composer::Composer *composer,
+  bool ConvertToTransliteration(const composer::Composer &composer,
                                 transliteration::TransliterationType type);
 
   // Convert the current composition to half-width characters.
   // NOTE(komatsu): This function might be merged to ConvertToTransliteration.
-  bool ConvertToHalfWidth(const composer::Composer *composer);
+  bool ConvertToHalfWidth(const composer::Composer &composer);
 
   // Switch the composition to Hiragana, full-width Katakana or
   // half-width Katakana by rotation.
-  bool SwitchKanaType(const composer::Composer *composer);
+  bool SwitchKanaType(const composer::Composer &composer);
 
   // Send a suggestion request to the converter.
-  bool Suggest(const composer::Composer *composer);
-  bool SuggestWithPreferences(const composer::Composer *composer,
+  bool Suggest(const composer::Composer &composer);
+  bool SuggestWithPreferences(const composer::Composer &composer,
                               const ConversionPreferences &preferences);
 
   // Send a prediction request to the converter.
-  bool Predict(const composer::Composer *composer);
-  bool PredictWithPreferences(const composer::Composer *composer,
+  bool Predict(const composer::Composer &composer);
+  bool PredictWithPreferences(const composer::Composer &composer,
                               const ConversionPreferences &preferences);
 
+  // Send a prediction request to the converter.
+  // The result is added at the tail of existing candidate list as "suggestion"
+  // candidates.
+  bool ExpandSuggestion(const composer::Composer &composer);
+  bool ExpandSuggestionWithPreferences(
+      const composer::Composer &composer,
+      const ConversionPreferences &preferences);
+
   // Clear conversion segments, but keep the context.
   void Cancel();
 
@@ -109,15 +113,42 @@ class SessionConverter : public SessionConverterInterface {
   // Fix the conversion with the current status.
   void Commit();
 
-  // Fix the suggestion candidate.
-  void CommitSuggestion(size_t index);
+  // Fix the suggestion candidate. Stores the number of characters in the key
+  // of the committed candidate to committed_key_size.
+  // For example, assume that "日本語" was suggested as a candidate for "にほ".
+  // The key of the candidate is "にほんご". Therefore, when the candidate is
+  // committed by this function, committed_key_size will be set to 4.
+  // True is returned if the suggestion is successfully committed.
+  bool CommitSuggestionByIndex(size_t index,
+                               const composer::Composer &composer,
+                               size_t *committed_key_size);
+
+  // Select a candidate and commit the selected candidate.  True is
+  // returned if the suggestion is successfully committed.
+  bool CommitSuggestionById(int id,
+                            const composer::Composer &composer,
+                            size_t *committed_key_size);
 
   // Fix only the conversion of the first segment, and keep the rest.
-  void CommitFirstSegment(composer::Composer *composer);
+  // The caller should delete characters from composer based on returned
+  // |committed_key_size|.
+  // If |committed_key_size| is 0, this means that there is only a segment
+  // so Commit() method is called instead. In this case, the caller
+  // should not delete any characters.
+  void CommitFirstSegment(size_t *committed_key_size);
 
   // Commit the preedit string represented by Composer.
   void CommitPreedit(const composer::Composer &composer);
 
+  // Commit the specified number of characters at the head of the preedit
+  // string represented by Composer.
+  // The caller should delete characters from composer based on returned
+  // |committed_size|.
+  // TODO(yamaguchi): Enhance to support the conversion mode.
+  void CommitHead(size_t count,
+                  const composer::Composer &composer,
+                  size_t *committed_size);
+
   // Revert the last "Commit" operation
   void Revert();
 
@@ -132,12 +163,12 @@ class SessionConverter : public SessionConverterInterface {
   void SegmentWidthShrink();
 
   // Move the focus of candidates.
-  void CandidateNext();
+  void CandidateNext(const composer::Composer &composer);
   void CandidateNextPage();
   void CandidatePrev();
   void CandidatePrevPage();
   // Move the focus to the candidate represented by the id.
-  void CandidateMoveToId(int id);
+  void CandidateMoveToId(int id, const composer::Composer &composer);
   // Move the focus to the index from the beginning of the current page.
   void CandidateMoveToPageIndex(size_t index);
   // Move the focus to the candidate represented by the shortcut.  If
@@ -149,19 +180,48 @@ class SessionConverter : public SessionConverterInterface {
   void SetCandidateListVisible(bool visible);
 
   // Fill protocol buffers and update the internal status.
-  void PopOutput(commands::Output *output);
+  void PopOutput(const composer::Composer &composer, commands::Output *output);
 
   // Fill protocol buffers
-  void FillOutput(commands::Output *output) const;
+  void FillOutput(
+      const composer::Composer &composer, commands::Output *output) const;
 
-  const string &GetDefaultResult() const;
+  // Fill context information
+  void FillContext(commands::Context *context) const;
+
+  // Get/Set segments
+  void GetSegments(Segments *dest) const;
+  void SetSegments(const Segments &src);
+
+  // Remove tail part of history segments
+  void RemoveTailOfHistorySegments(size_t num_of_characters);
+
+  // Fill protocol buffers with all flatten candidate words.
+  void FillAllCandidateWords(commands::CandidateList *candidates) const;
+
+  // Accessor
+  const commands::Result &GetResult() const;
+  const CandidateList &GetCandidateList() const;
+  const OperationPreferences &GetOperationPreferences() const;
+  SessionConverterInterface::State GetState() const;
+  size_t GetSegmentIndex() const;
+  const Segment &GetPreviousSuggestions() const;
 
   // Fill segments with the conversion preferences.
   static void SetConversionPreferences(
       const ConversionPreferences &preferences,
       Segments *segments);
 
+  // Copy SessionConverter
+  // TODO(hsumita): Copy all member variables.
+  // Currently, converter_ is not copied.
+  void CopyFrom(const SessionConverterInterface &src);
+
  private:
+  FRIEND_TEST(SessionConverterTest, AppendCandidateList);
+  FRIEND_TEST(SessionConverterTest, GetPreeditAndGetConversion);
+  FRIEND_TEST(SessionConverterTest, PartialSuggestion);
+
   // Reset the result value stored at the previous command.
   void ResetResult();
 
@@ -174,40 +234,58 @@ class SessionConverter : public SessionConverterInterface {
   // Notify the converter that the current segment is fixed.
   void SegmentFix();
 
-  // Get preedit and conversion from segment(index) to segment(index + size).
-  void GetPreeditAndConversion(size_t index, size_t size,
-                               string *preedit, string *conversion) const;
+  // Get preedit from segment(index) to segment(index + size).
+  void GetPreedit(size_t index, size_t size, string *preedit) const;
+  // Get conversion from segment(index) to segment(index + size).
+  void GetConversion(size_t index, size_t size, string *conversion) const;
+
+  // Perform the command if the command candidate is selected.  True
+  // is returned if a command is performed.
+  bool MaybePerformCommandCandidate(size_t index, size_t size) const;
 
   // Update internal states
-  void UpdateResult(size_t index, size_t size);
+  bool UpdateResult(size_t index, size_t size);
+
+  // Fill the candidate list with the focused segment's candidates.
+  // This method does not clear the candidate list before processing.
+  // Only the candidates of which id is not existent in the candidate list
+  // are appended. Other candidates are ignored.
+  void AppendCandidateList();
+  // Clear the candidate list and fill it with the focused segment's candidates.
   void UpdateCandidateList();
-  void InitSegment(const size_t segment_index);
 
   // Return the candidate index to be used by the converter.
   int GetCandidateIndexForConverter(const size_t segment_index) const;
 
   // if focus_id is pointing to the last of suggestions,
   // call StartPrediction().
-  void MaybeExpandPrediction();
+  void MaybeExpandPrediction(const composer::Composer &composer);
+
+  // Return the value of candidate to be used by the converter.
+  string GetSelectedCandidateValue(size_t segment_index) const;
 
   // Return the candidate to be used by the converter.
   const Segment::Candidate &GetSelectedCandidate(size_t segment_index) const;
 
+  // Returns the length of committed candidate's key in characters.
+  // True is returned if the selected candidate is successfully committed.
+  bool CommitSuggestionInternal(const composer::Composer &composer,
+                                size_t *committed_length);
+
   void FillConversion(commands::Preedit *preedit) const;
   void FillResult(commands::Result *result) const;
   void FillCandidates(commands::Candidates *candidates) const;
 
-  State state_;
+  bool IsEmptySegment(const Segment &segment) const;
 
-  bool active_;
+  SessionConverterInterface::State state_;
 
-  const composer::Composer *composer_;
   const ConverterInterface *converter_;
   scoped_ptr<Segments> segments_;
   size_t segment_index_;
 
   // Previous suggestions to be merged with the current predictions.
-  vector<Segment::Candidate> previous_suggestions_;
+  Segment previous_suggestions_;
 
   // Default conversion preferences.
   ConversionPreferences conversion_preferences_;
@@ -215,19 +293,15 @@ class SessionConverter : public SessionConverterInterface {
   // Preferences for user's operation.
   OperationPreferences operation_preferences_;
 
-  string composition_;
   commands::Result result_;
 
-  // Default result the converter generated without user's
-  // modifactions.  Note, this result is considered with user's
-  // histroy when ConversionPreferences::use_history is true.
-  string default_result_;
-
   scoped_ptr<CandidateList> candidate_list_;
   bool candidate_list_visible_;
 
   DISALLOW_COPY_AND_ASSIGN(SessionConverter);
 };
+
 }  // namespace session
 }  // namespace mozc
+
 #endif  // MOZC_SESSION_SESSION_CONVERTER_H_
