@@ -46,9 +46,9 @@
 #include "base/base.h"
 #include "base/config_file_stream.h"
 #include "base/singleton.h"
+#include "config/config_handler.h"
+#include "config/config.pb.h"
 #include "session/commands.pb.h"
-#include "session/config_handler.h"
-#include "session/config.pb.h"
 #include "session/internal/keymap.h"
 #include "session/state.pb.h"
 #include "usage_stats/usage_stats.h"
@@ -148,6 +148,19 @@ void SetConfigStats() {
   usage_stats::UsageStats::SetBoolean("ConfigUseSymbolConversion", use_symbol);
   const bool use_number = GET_CONFIG(use_number_conversion);
   usage_stats::UsageStats::SetBoolean("ConfigUseNumberConversion", use_number);
+  const bool use_emoticon = GET_CONFIG(use_emoticon_conversion);
+  usage_stats::UsageStats::SetBoolean("ConfigUseEmoticonConversion",
+                                      use_emoticon);
+  const bool use_calculator = GET_CONFIG(use_calculator);
+  usage_stats::UsageStats::SetBoolean("ConfigUseCalculator", use_calculator);
+  const bool use_t13n = GET_CONFIG(use_t13n_conversion);
+  usage_stats::UsageStats::SetBoolean("ConfigUseT13nConversion", use_t13n);
+  const bool use_zip_code = GET_CONFIG(use_zip_code_conversion);
+  usage_stats::UsageStats::SetBoolean("ConfigUseZipCodeConversion",
+                                      use_zip_code);
+  const bool use_spelling_correction = GET_CONFIG(use_spelling_correction);
+  usage_stats::UsageStats::SetBoolean("ConfigUseSpellingCorrection",
+                                      use_spelling_correction);
   const bool incognito = GET_CONFIG(incognito_mode);
   usage_stats::UsageStats::SetBoolean("ConfigIncognito", incognito);
 
@@ -159,6 +172,9 @@ void SetConfigStats() {
   const bool use_dictionary = GET_CONFIG(use_dictionary_suggest);
   usage_stats::UsageStats::SetBoolean("ConfigUseDictionarySuggest",
                                       use_dictionary);
+  const bool use_realtime_conversion = GET_CONFIG(use_realtime_conversion);
+  usage_stats::UsageStats::SetBoolean("ConfigUseRealtimeConversion",
+                                      use_realtime_conversion);
 
   const uint32 suggest_size = GET_CONFIG(suggestions_size);
   usage_stats::UsageStats::SetInteger("ConfigSuggestionsSize", suggest_size);
@@ -166,6 +182,9 @@ void SetConfigStats() {
   const bool use_auto_ime_turn_off = GET_CONFIG(use_auto_ime_turn_off);
   usage_stats::UsageStats::SetBoolean("ConfigUseAutoIMETurnOff",
                                       use_auto_ime_turn_off);
+  const bool use_cascading_window = GET_CONFIG(use_cascading_window);
+  usage_stats::UsageStats::SetBoolean("ConfigUseCascadingWindow",
+                                      use_cascading_window);
 
   const uint32 shift = GET_CONFIG(shift_key_mode_switch);
   usage_stats::UsageStats::SetInteger("ConfigShiftKeyModeSwitch", shift);
@@ -174,6 +193,21 @@ void SetConfigStats() {
   const uint32 numpad = GET_CONFIG(numpad_character_form);
   usage_stats::UsageStats::SetInteger("ConfigNumpadCharacterForm", numpad);
 
+  const bool use_auto_conversion = GET_CONFIG(use_auto_conversion);
+  usage_stats::UsageStats::SetBoolean("ConfigUseAutoConversion",
+                                      use_auto_conversion);
+  const uint32 auto_conversion_key = GET_CONFIG(auto_conversion_key);
+  usage_stats::UsageStats::SetInteger("ConfigAutoConversionKey",
+                                      auto_conversion_key);
+
+  const uint32 yen_sign_character = GET_CONFIG(yen_sign_character);
+  usage_stats::UsageStats::SetInteger("ConfigYenSignCharacter",
+                                      yen_sign_character);
+
+  const bool use_japanese_layout = GET_CONFIG(use_japanese_layout);
+  usage_stats::UsageStats::SetBoolean("ConfigUseJapaneseLayout",
+                                       use_japanese_layout);
+
   const bool ime_activation_key_customized = IMEActivationKeyCustomized();
   usage_stats::UsageStats::SetBoolean("IMEActivationKeyCustomized",
                                       ime_activation_key_customized);
@@ -191,9 +225,9 @@ bool FindInCandidates(const string &value,
 }
 
 // Return session state mode from candidate mode
-session::SessionState::Mode GetSessionModeFromCandidates(
-    const commands::Candidates &candidates) {
-  switch (candidates.category()) {
+session::SessionState::Mode GetSessionModeFromCandidateList(
+    const commands::CandidateList &candidate_list) {
+  switch (candidate_list.category()) {
     case commands::CONVERSION:
       return session::SessionState::CONVERSION;
     case commands::PREDICTION:
@@ -201,7 +235,7 @@ session::SessionState::Mode GetSessionModeFromCandidates(
     case commands::SUGGESTION:
       return session::SessionState::SUGGESTION;
     default:
-      DCHECK(false) << "invalid candidate category";
+      DLOG(FATAL) << "invalid candidate category";
       return session::SessionState::COMPOSITION;
   }
 }
@@ -210,7 +244,10 @@ session::SessionState::Mode GetSessionModeFromCandidates(
 bool IsMouseSelect(const commands::Input &input) {
   return (input.type() == commands::Input::SEND_COMMAND &&
           input.has_command() &&
-          input.command().type() == commands::SessionCommand::SELECT_CANDIDATE);
+          (input.command().type() ==
+              commands::SessionCommand::SELECT_CANDIDATE ||
+           input.command().type() ==
+              commands::SessionCommand::SUBMIT_CANDIDATE));
 }
 
 // Return true if resegmented
@@ -274,6 +311,7 @@ bool CheckCandidateCategory(const SessionState *state,
   return (state->has_candidates() &&
           state->candidates().category() == category);
 }
+
 }  // namespace
 
 class EventConverter {
@@ -397,6 +435,7 @@ void SessionUsageObserver::SaveStats() {
   }
   boolean_cache_.clear();
 
+
   update_count_ = 0;
   usage_stats::UsageStats::Sync();
   VLOG(3) << "Save Stats";
@@ -485,17 +524,16 @@ void SessionUsageObserver::UpdateMode(const commands::Input &input,
 
   // Mouse select and no candidate window now.
   if (IsMouseSelect(input)) {
-    DCHECK(state->has_candidates());
-    if (state->has_candidates()) {
+    if (state->has_all_candidate_words()) {
       state->set_mode(
-          GetSessionModeFromCandidates(state->candidates()));
+          GetSessionModeFromCandidateList(state->all_candidate_words()));
     }
     return;
   }
 
-  if (output.has_candidates()) {
+  if (output.has_all_candidate_words()) {
     state->set_mode(
-        GetSessionModeFromCandidates(output.candidates()));
+        GetSessionModeFromCandidateList(output.all_candidate_words()));
     return;
   }
 
@@ -700,6 +738,29 @@ void SessionUsageObserver::UpdateState(const commands::Input &input,
   }
 }
 
+void SessionUsageObserver::UpdateClientSideStats(const commands::Input &input,
+                                                 SessionState *state) {
+  switch (input.command().usage_stats_event()) {
+    case commands::SessionCommand::INFOLIST_WINDOW_SHOW:
+      if (!state->has_start_infolist_window_time()) {
+        state->set_start_infolist_window_time(time(NULL));
+      }
+      break;
+    case commands::SessionCommand::INFOLIST_WINDOW_HIDE:
+      if (state->has_start_infolist_window_time()) {
+        const uint64 infolist_duration
+            = time(NULL) - state->start_infolist_window_time();
+        DLOG(INFO) << "infolist_duration:" << infolist_duration;
+        UpdateTiming("InfolistWindowDuration", infolist_duration);
+        state->clear_start_infolist_window_time();
+      }
+      break;
+    default:
+      LOG(WARNING) << "client side usage stats event has invalid category";
+      break;
+  }
+}
+
 void SessionUsageObserver::EvalSendKey(const commands::Input &input,
                                        const commands::Output &output) {
   if (input.has_key() && input.key().has_key_code()) {
@@ -751,9 +812,9 @@ void SessionUsageObserver::CheckOutput(const commands::Input &input,
     // We should check the candidate contents because suggestion
     // candidates are shown automatically.
     IncrementCount("CommitFromSuggestion");
-    if (state->selected_indices_size() == 0) {
+    if (input.command().type() == commands::SessionCommand::SUBMIT_CANDIDATE ||
+        state->selected_indices_size() == 0) {
       // Committed zero-query suggest candidate
-      // by using SEGMENT_FOCUS_RIGHT_OR_COMMIT command.
       UpdateCandidateStats("SuggestionCandidates", input.command().id());
     } else {
       const uint32 index = state->selected_indices(0);
@@ -805,9 +866,17 @@ void SessionUsageObserver::CheckOutput(const commands::Input &input,
     UpdateTiming("SubmittedLength", total_len);
     UpdateTiming("SubmittedSegmentNumber",state->preedit().segment_size());
     IncrementCountBy("SubmittedTotalLength", total_len);
+  } else {
+    // Zero-query Suggest
+    size_t length = Util::CharsLen(submit_value.c_str(), submit_value.size());
+    UpdateTiming("SubmittedSegmentLength", length);
+    UpdateTiming("SubmittedLength", length);
+    UpdateTiming("SubmittedSegmentNumber", 1);
+    IncrementCountBy("SubmittedTotalLength", length);
   }
 }
 
+
 void SessionUsageObserver::EvalCommandHandler(
     const commands::Command &command) {
   const commands::Input &input = command.input();
@@ -901,6 +970,16 @@ void SessionUsageObserver::EvalCommandHandler(
     IncrementCount("MouseSelect");
   }
 
+  // Client side event
+  if ((input.type() == commands::Input::SEND_COMMAND) &&
+      (input.has_command()) &&
+      (input.command().type() ==
+           commands::SessionCommand::USAGE_STATS_EVENT) &&
+      (input.command().has_usage_stats_event())) {
+    UpdateClientSideStats(input, state);
+  }
+
+
   if ((input.type() == commands::Input::SEND_COMMAND ||
        input.type() == commands::Input::SEND_KEY) &&
       output.has_consumed() &&
