@@ -34,7 +34,10 @@
 #include "base/base.h"
 #include "base/logging.h"
 #include "base/version.h"
-#include "session/config_handler.h"
+#include "config/config_handler.h"
+#include "languages/global_language_spec.h"
+#include "languages/japanese/lang_dep_spec.h"
+#include "session/japanese_session_factory.h"
 #include "unix/ibus/main.h"
 #include "unix/ibus/mozc_engine.h"
 #include "unix/ibus/path_util.h"
@@ -50,12 +53,14 @@ IBusConfig *g_config = NULL;
 #endif
 
 #ifndef OS_CHROMEOS
+#ifndef NO_LOGGING
 void EnableVerboseLog() {
   const int kDefaultVerboseLevel = 1;
   if (mozc::Logging::GetVerboseLevel() < kDefaultVerboseLevel) {
     mozc::Logging::SetVerboseLevel(kDefaultVerboseLevel);
   }
 }
+#endif
 
 void IgnoreSigChild() {
   // Don't wait() child process termination.
@@ -137,11 +142,17 @@ void InitIBusComponent(bool executed_by_ibus_daemon) {
 
 int main(gint argc, gchar **argv) {
   InitGoogle(argv[0], &argc, &argv, true);
-  ibus_init();
-  InitIBusComponent(FLAGS_ibus);
+  mozc::japanese::LangDepSpecJapanese spec;
+  mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(&spec);
 #ifdef OS_CHROMEOS
   // On Chrome OS, mozc does not store the config data to a local file.
   mozc::config::ConfigHandler::SetConfigFileName("memory://config.1.db");
+  mozc::session::JapaneseSessionFactory session_factory;
+  mozc::session::SessionFactoryManager::SetSessionFactory(&session_factory);
+#endif  // OS_CHROMEOS
+  ibus_init();
+  InitIBusComponent(FLAGS_ibus);
+#ifdef OS_CHROMEOS
   mozc::ibus::MozcEngine::InitConfig(g_config);
 #else
 #ifndef NO_LOGGING
