@@ -41,7 +41,7 @@
 namespace mozc {
 
 namespace client {
-class SessionInterface;
+class ClientInterface;
 }
 
 namespace ibus {
@@ -138,6 +138,11 @@ class MozcEngine : public EngineInterface {
   // Updates the candidate window based on the content of |output|.
   bool UpdateCandidates(IBusEngine *engine,
                         const commands::Output &output);
+  // Updates the deletion range message based on the content of |output|.
+  bool UpdateDeletionRange(IBusEngine *engine, const commands::Output &output);
+
+  // Updates the callback message based on the content of |output|.
+  bool ExecuteCallback(IBusEngine *engine, const commands::Output &output);
   // Updates the configuration.
 #ifdef OS_CHROMEOS
 #if IBUS_CHECK_VERSION(1, 3, 99)
@@ -174,7 +179,7 @@ class MozcEngine : public EngineInterface {
 
   uint64 last_sync_time_;
   scoped_ptr<KeyTranslator> key_translator_;
-  scoped_ptr<client::SessionInterface> session_;
+  scoped_ptr<client::ClientInterface> client_;
 
   IBusPropList *prop_root_;
   IBusProperty *prop_composition_mode_;
@@ -194,9 +199,10 @@ class MozcEngine : public EngineInterface {
   // This is a workaround.  See the implementation of ProcessKeyEvent().
   bool ignore_reset_for_deletion_range_workaround_;
 
-  DISALLOW_COPY_AND_ASSIGN(MozcEngine);
   friend class LaunchToolTest;
   FRIEND_TEST(LaunchToolTest, LaunchToolTest);
+
+  DISALLOW_COPY_AND_ASSIGN(MozcEngine);
 };
 
 }  // namespace ibus
