@@ -33,7 +33,6 @@
 #include <string>
 
 #include "base/base.h"
-#include "client/session_interface.h"
 #include "session/commands.pb.h"
 
 namespace scim {
@@ -48,9 +47,8 @@ class IPCClientInterface;
 class IPCClientFactoryInterface;
 
 namespace client {
-
+class ClientInterface;
 class ServerLauncherInterface;
-
 }  // namespace client
 
 }  // namespace mozc
@@ -125,8 +123,11 @@ class MozcConnection : public MozcConnectionInterface {
       string *out_error) const;
 
   const scoped_ptr<ScimKeyTranslator> translator_;
-  scoped_ptr<mozc::client::SessionInterface> session_;
   mozc::config::Config::PreeditMethod preedit_method_;
+  // Keep definition order of client_factory_ and client_.
+  // We should delete client_ before deleting client_factory_.
+  scoped_ptr<mozc::IPCClientFactoryInterface> client_factory_;
+  scoped_ptr<mozc::client::ClientInterface> client_;
 
   DISALLOW_COPY_AND_ASSIGN(MozcConnection);
 };
