@@ -40,9 +40,9 @@
 #include "base/encryptor.h"
 #include "base/mutex.h"
 #include "base/singleton.h"
-#include "base/stats_config_util.h"
 #include "base/util.h"
 #include "base/version.h"
+#include "config/stats_config_util.h"
 #include "storage/registry.h"
 #include "usage_stats/usage_stats.pb.h"
 #include "usage_stats/upload_util.h"
@@ -127,6 +127,7 @@ ClientIdInterface &GetClientIdHandler() {
     return *g_client_id_handler;
   }
 }
+
 }  // namespace
 
 const uint32 UsageStats::kDefaultSchedulerDelay = 60*1000;  // 1 min
@@ -454,6 +455,7 @@ void UsageStats::SetBoolean(const string &name, bool val) {
   }
 }
 
+
 void UsageStats::Sync() {
   if (!storage::Registry::Sync()) {
     LOG(ERROR) << "sync failed";
