@@ -1,4 +1,4 @@
-// Copyright 2010, Google Inc.
+// Copyright 2010-2011, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,11 +30,13 @@
 #ifndef MOZC_USAGE_STATS_USAGE_STATS_H_
 #define MOZC_USAGE_STATS_USAGE_STATS_H_
 
+#include <map>
 #include <string>
 #include <utility>
 #include <vector>
 #include "base/util.h"
 #include "testing/base/public/gunit_prod.h"  // FRIEND_TEST
+#include "usage_stats/usage_stats.pb.h"
 
 namespace mozc {
 namespace usage_stats {
@@ -51,6 +53,12 @@ class ClientIdInterface {
 
 class UsageStats {
  public:
+  // Default values for scheduler.
+  static const uint32 kDefaultSchedulerDelay;
+  static const uint32 kDefaultSchedulerRandomDelay;
+  static const uint32 kDefaultScheduleInterval;
+  static const uint32 kDefaultScheduleMaxInterval;
+
   UsageStats();
   virtual ~UsageStats();
 
@@ -81,7 +89,6 @@ class UsageStats {
     UpdateTimingBy(name, vector<uint32>(1, val));
   }
 
-
   // Sets integer value
   // Replaces old value with val
   static void SetInteger(const string &name, int val);
@@ -100,6 +107,7 @@ class UsageStats {
   // (for debugging)
   static bool IsListed(const string &name);
 
+
  private:
   FRIEND_TEST(ClientIdTest, CreateClientIdTest);
   FRIEND_TEST(ClientIdTest, GetClientIdTest);
